@@ -2,7 +2,7 @@
 
 package Exception::System;
 use 5.006;
-our $VERSION = 0.09_01;
+our $VERSION = 0.09_02;
 
 =head1 NAME
 
@@ -134,6 +134,18 @@ L<Exception::Base>
 
 =back
 
+=head1 CONSTANTS
+
+=over
+
+=item ATTRS
+
+Declaration of class attributes as reference to hash.
+
+See L<Exception::Base> for details.
+
+=back
+
 =head1 ATTRIBUTES
 
 Class attributes are implemented as values of blessed hash.  The attributes of
